gchecky.controller.html_order

Package gchecky :: Module controller :: Class html_order |
[hide private]
[frames] | no frames]

# Class html_order

source code

    object --+
             |
            html_order

TODO:

Instance Methods | [hide private]
html(self) Return the html form containing two required hidden fields and the submit button in the form of Google Checkout button image. | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
| cart = `None`
| signature = `None`
| url = `None`
| button = `None`
| xml = `None`

Properties | [hide private]
Inherited from `object`: `__class__`